@@ -4,7 +4,10 @@ module HTTP
 
     def perform(request, options)
       return __perform__(request, options) unless webmock_enabled?
-      WebMockPerform.new(request) { __perform__(request, options) }.exec
+
+      response = WebMockPerform.new(request) { __perform__(request, options) }.exec
+      options.features.each { |_name, feature| response = feature.wrap_response(response) }
+      response
     end
 
     def webmock_enabled?
